---
Before starting the demo, please read the following instructions.

---
### **Hardware and Software Requirements**

**Hardware**
- [BQ76952EVM](https://www.ti.com/tool/BQ76952EVM)
- [MSP-EXP430FR2355 LaunchPad](https://www.ti.com/tool/MSP-EXP430FR2355)
- Micro USB cable
- Female-to-female jumper wires
- DC power supply with hook or alligator clip test leads
- 18- to 22-gauge wires
- Wire strippers
- Small straight screwdriver

**Software**
- [Battery Management Studio (bqStudio)](www.ti.com/tool/BQSTUDIO) NOTE: Test version only!
- GUI Composer

---
### **Setup**

**Configure BQ76952EVM to power MSP-EXP430FR2355 LaunchPad**

On your PC,
- Download the [bqStudio software](www.ti.com/tool/BQSTUDIO) (test version only) from the tool folder or search for it on www.ti.com.
- Install the bqStudio software. See Section 3.2 in [EVM user's guide](https://www.ti.com/lit/pdf/sluuc33) for more details.

On the BQ EVM,
- Ensure all cell simulator shunts are populated on headers J14 and J23.
- Make sure these shunt settings are selected:
    - SDA (J16): uC_SDA option
    - SCL (J19): uC_SCL option
    - SDA_PU (J15): Remove shunt
    - SCL_PU (J18): Remove shunt
- Connect the USB cable to EVM's USB connector and PC.
- Use a screw driver to attach the wires to CELL16 terminal (J1) and BAT- terminal (J4).
- Connect a 0 V DC power supply capable of 250 mA minimum.
    - Connect the positive lead to wire on CELL16 terminal and the negative lead to wire on BAT- terminal.
    - Adjust the power supply to approximately 48 V (or a voltage as low as 13 V).
- Press and release the WAKE switch (S2).

On your PC,
- Start the bqStudio software. The GUI should open with a register display if everything was connected correctly.
    - Click on the Scan button to enable repeated update of the display.
    - The power supply may be adjusted within range of the EVM to observe voltage changes in the GUI register display.
    - For a more advanced view, enable it under Window > Preferences > All Global Settings > Show Advanced Views > Apply.
- Configure the BQ device to enable REG1 3.3 V output to provide power for MSP-EXP430FR2355 LaunchPad.
    - Select the Data Memory button in the bqStudio window, then click the Settings button.
    - Under Configuration section, change the value of REG0 Config to 0x01 (enables pre-regulator for REG1) and hit Enter.
    - Change REG12 Config to 0x0d (enables REG1 and sets voltage level to 3.3 V) and hit Enter.
    - Optional - To preserve these settings after power to EVM is turned off, the OTP can be written. However, the OTP can only be written up to 8 times, so do this as infrequently as possible. NOTE: Battery voltage must be between 10 and 12 V. To do that, turn off Auto Refresh in the Dashboard first. Select Data Memory and then select the Program OTP button. Click the Check OTP Programming Possible button. Status should show up as green. If status passes, select the Send Reset After Programming box and then click Program Data Memory to OTP Memory to program the current register settings onto the BQ device.
- When complete, exit the bqStudio software and unplug the USB cable from the EVM.
- NOTE: Keep the power supply on for future steps.

**Make hardware connections between BQ EVM and LaunchPad**

On the EVM,
- Remove the SDA and SCL shunts from headers J16 and J19, respectively.
- Populate the SDA_PU and SCL_PU shunts on headers J15 and J18, respectively.
- To ensure reliable I2C communication with the LaunchPad, use two jumper wires to lower the effective pull-up resistance on the EVM from 10 kΩ to ~5 kΩ.
    - Right ALERT_PU pin (J20.1) to middle SDA pin (J16.2)
    - Right HDQ_PU pin (J12.1) to middle SCL pin (J19.2)

On the LaunchPad,
- Remove the 3V3 and 5V shunts from the isolation jumper block J101. Make sure all other shunts are populated on J101.
- Use short jumper wires to make the power and I2C connections between the EVM and LaunchPad. See table below for proper connection order and pin descriptions.
- Attach the LaunchPad to your PC using USB cable.

![](images/i2c_communication_conn.jpg)

On your PC,
- Open the GUI demo in a browser (already done if you're reading this).
- The GUI should automatically connect to and program your LaunchPad.
    - You can click the ![](images/disconnected.gif) button in the status bar at the bottom of the GUI to connect to the EVM.
    - Once connected, clicking on the ![](images/connected.gif) button in the status bar will disconnect from the EVM.
- LED2 will toggle on the LaunchPad indicating that communication with the GUI is working correctly.
- View the BQ data from the EVM in the GUI.
- If the status bar shows the LaunchPad is connected but the parameters in the GUI are not updating, press the Reset button (S3) on the LaunchPad.

To see this README again once it has been closed, please click Help > View README.md.